
subroutine CalcEnergy(Pos, L, rc, Dim, NAtom, xwL, xwR, PEnergy)
    implicit none
    integer, intent(in) :: Dim, NAtom
    real(8), intent(in), dimension(0:NAtom-1, 0:Dim-1) :: Pos
    real(8), intent(in) :: L, rc, xwL, xwR
    real(8), intent(out) :: PEnergy
    !======== YOUR CODE HERE ========
    real(8), dimension(0:Dim-1) :: rij, Posi
    real(8) :: dwL, dwR, d2, invd2
    real(8) :: rc2, PEcut, PEwL, PEwR
    integer :: i, j
    PEnergy = 0.
    PEcut = -4.*(rc**(-12)-rc**(-6))
    rc2=rc*rc

    PEwL = 0.
    PEwR = 0.   

    do i=0, NAtom-1
        Posi = Pos(i,:)        

        do j = i+1, NAtom-1
            rij = Pos(j,:)-Posi
            rij(1:2) = rij(1:2) - L*dnint(rij(1:2)/L)  !min image distance
            d2 = sum(rij * rij)
            if (d2 > rc2) then
                cycle
            end if
            invd2=1./d2                
            PEnergy=PEnergy+4.*(invd2**6-invd2**3)+PEcut
        enddo
        dwL=abs(Posi(0)-xwL)
        dwR=abs(Posi(0)-xwR)
        PEnergy = PEnergy + 3.1*((1./15.)/(dwL)**9-(1./2.)/(dwL)**3)
        PEnergy = PEnergy + 3.1*((1./15.)/(dwR)**9-(1./2.)/(dwR)**3)

    enddo
end subroutine


subroutine CalcEnergyForces(Pos, L, rc, Dim, NAtom, xwL, xwR, PEnergy, Forces, PEwL, FwL, PEwR, FwR)
    implicit none
    integer, intent(in) :: Dim, NAtom
    real(8), intent(in), dimension(0:NAtom-1, 0:Dim-1) :: Pos
    real(8), intent(in) :: L, rc, xwL, xwR
    real(8), intent(out) :: PEnergy, PEwL, PEwR, FwL, FwR
    real(8), intent(inout), dimension(0:NAtom-1, 0:Dim-1) :: Forces


!f2py intent(in, out) :: Forces
    !======== YOUR CODE HERE ========0:Dim-1
    real(8), dimension(0:Dim-1) :: rij, Fij, Posi
    real(8) :: dwL, dwR,d2,invd2
    real(8) :: rc2, PEcut, FLi, FRi
    integer :: i, j
    PEnergy = 0.
    Forces = 0.
    PEcut = -4.*(rc**(-12)-rc**(-6))
    rc2=rc*rc

    PEwL = 0.
    PEwR = 0.
    FwL = 0.
    FwR = 0.

    do i =0,NAtom-1
        Posi=Pos(i,:)
                
        do j = i+1,NAtom-1
            rij = Pos(j,:)-Posi
            rij(1:2) = rij(1:2) - L*dnint(rij(1:2)/L)  !min image distance          
            d2 = sum(rij * rij)
            if (d2 > rc2) then
                cycle
            end if
            invd2=1./d2                
            PEnergy=PEnergy+4.*(invd2**6-invd2**3)+PEcut
            Fij=-24.*rij*(2.*invd2**6-invd2**3)*invd2
            Forces(i,:)=Forces(i,:)+Fij
            Forces(j,:)=Forces(j,:)-Fij
        enddo
        dwL=abs(Posi(0)-xwL)
        dwR=abs(Posi(0)-xwR)
        PEnergy = PEnergy + 3.1*((1./15.)/(dwL)**9-(1./2.)/(dwL)**3)
        PEnergy = PEnergy + 3.1*((1./15.)/(dwR)**9-(1./2.)/(dwR)**3)
        PEwL = PEwL + 3.1*((1./15.)/(dwL)**9-(1./2.)/(dwL)**3)
        PEwR = PEwR + 3.1*((1./15.)/(dwR)**9-(1./2.)/(dwR)**3)
        FLi = 3.1*((3./5.)/(dwL)**10-(3./2.)/(dwL)**4)
        FRi = -3.1*((3./5.)/(dwR)**10-(3./2.)/(dwR)**4)        
        Forces(i,0) = Forces(i,0)+FLi+FRi
        FwL = FwL - FLi
        FwR = FwR - FRi        
    enddo
end subroutine

subroutine VVIntegrate(Pos, Vel, Accel, L, rc, Dim, NAtom, xwL, xwR, dt, KEnergy, PEnergy, PEwL, PEwR, FwL, FwR)
    implicit none
    integer, intent(in) :: Dim, NAtom
    real(8), intent(in) :: L, rc, dt, xwL, xwR
    real(8), intent(inout), dimension(0:NAtom-1, 0:Dim-1) :: Pos, Vel, Accel
!f2py intent(in,out) :: Pos, Vel, Accel
    real(8), intent(out) :: KEnergy, PEnergy, PEwL, PEwR, FwL, FwR
    external :: CalcEnergyForces
    Pos = Pos + dt * Vel + 0.5 * dt*dt * Accel
    Vel = Vel + 0.5 * dt * Accel
!    call CalcEnergyForces(Pos, L, rc, PEnergy, Accel, Dim, NAtom)
    call CalcEnergyForces(Pos, L, rc, Dim, NAtom, xwL, xwR, PEnergy, Accel, PEwL, FwL, PEwR, FwR)
    Vel = Vel + 0.5 * dt * Accel
    KEnergy = 0.5 * sum(Vel*Vel)
end subroutine